@@ -1,21 +1,24 @@
 package Forest::Tree::Roles::HasNodeFormatter;
 use Moose::Role;
 
-our $VERSION   = '0.07';
+our $VERSION   = '0.08';
 our $AUTHORITY = 'cpan:STEVAN';
 
 has 'node_formatter' => (
-    is      => 'rw', 
-    isa     => 'CodeRef',
+    is      => 'rw',
+    isa     => 'CodeRef|Str',
     lazy    => 1,
-    default => sub { 
-        sub { (shift)->node  || 'undef' } 
+    default => sub {
+        sub { (shift)->node  || 'undef' }
     }
 );
 
 sub format_node {
-    my $self = shift;
-    $self->node_formatter->(@_)
+    my ( $self, $node, @args ) = @_;
+
+    my $fmt = $self->node_formatter;
+
+    $node->$fmt(@args);
 }
 
 no Moose::Role; 1;
@@ -26,21 +29,15 @@ __END__
 
 =head1 NAME
 
-=head1 SYNOPSIS
+Forest::Tree::Roles::HasNodeFormatter - Simple role for custom node formatters
 
 =head1 DESCRIPTION
 
-=head1 METHODS 
-
-=over 4
-
-=item B<>
-
-=back
+Simple role for nodes that have custom formatters
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no 
+All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
@@ -50,7 +47,7 @@ Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2009 Infinity Interactive, Inc.
+Copyright 2008-2010 Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
