@@ -1,12 +1,13 @@
 package Forest::Tree::Writer;
 use Moose::Role;
 
-our $VERSION   = '0.07';
+our $VERSION   = '0.08';
 our $AUTHORITY = 'cpan:STEVAN';
 
 has 'tree' => (
-    is  => 'rw',
-    isa => 'Forest::Tree',
+    is          => 'rw',
+    isa         => 'Forest::Tree::Pure',
+    required    => 1,
 );
 
 requires 'as_string';
@@ -66,7 +67,7 @@ Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2009 Infinity Interactive, Inc.
+Copyright 2008-2010 Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
