@@ -1,7 +1,7 @@
 package Forest::Tree::Writer::SimpleASCII;
 use Moose;
 
-our $VERSION   = '0.07';
+our $VERSION   = '0.08';
 our $AUTHORITY = 'cpan:STEVAN';
 
 with 'Forest::Tree::Writer',
@@ -10,13 +10,21 @@ with 'Forest::Tree::Writer',
 sub as_string {
     my ($self) = @_;
     my $out;
-    
-    $self->tree->traverse(sub {
-        my $t = shift;
-        $out .= (('    ' x $t->depth) . $self->format_node($t) . "\n");
-    });
-    
-    return $out;
+
+    return join( "", map { "$_\n" }
+        $self->tree->fmap_cont(sub {
+            my ( $t, $cont, %args ) = @_;
+
+            if ( $t->has_node ) {
+                return (
+                    $self->format_node($t),
+                    map { "    $_" } $cont->(),
+                );
+            } else {
+                return $cont->();
+            }
+        }),
+    );
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -35,7 +43,7 @@ Forest::Tree::Writer::SimpleASCII - A simple ASCII writer for Forest::Tree heira
 
 This is a simple writer which draws a tree in ASCII.
 
-=head1 METHODS 
+=head1 METHODS
 
 =over 4
 
@@ -45,7 +53,7 @@ This is a simple writer which draws a tree in ASCII.
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no 
+All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
@@ -55,7 +63,7 @@ Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2009 Infinity Interactive, Inc.
+Copyright 2008-2010 Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
